@@ -37,56 +37,51 @@
 
 
 
+.breakAtDateLine <- function(x) {
+	r <- range(x[,1]) 
+	r <- r[2] - r[1]
+	if (r > 200) {
+		dif <- abs(x[-nrow(x),1] - x[-1,1])
+		tr <- which(dif==max(dif))
+		x1 <- x[1:tr, ,drop=FALSE]
+		x2 <- x[(tr+1):nrow(x), ,drop=FALSE]
+		if (x1[tr,1] < 0) { 
+			x1[tr,1] <- -180 
+			x2[1,1] <- 180
+		} else { 
+			x1[tr,1] <- 180 
+			x2[1,1] <- -180 
+		}
+		if (nrow(x1) <= 1) {
+			res <- x2
+		} else if (nrow(x2) <= 1) {
+			res <- x1
+		} else {
+			res <- list(x1, x2)
+		}
+		return(res)
+	} 
+	return(x)
+}
+
+
+
 gcIntermediate <- function( p1, p2, n=50, breakAtDateLine=FALSE, addStartEnd=FALSE, sp=FALSE, sepNA=FALSE) {
 # Intermediate points on a great circle
 # source: http://williams.best.vwh.net/avform.htm
 
-#	internal=FALSE 
-
 	p1 <- .pointsToMatrix(p1)
 	p2 <- .pointsToMatrix(p2)
 	p <- cbind(p1[,1], p1[,2], p2[,1], p2[,2], as.vector(n))
 	res <- list()
 
 	for (i in 1:nrow(p)) {
-		#if (internal) {
 		x <- .interm(p[i,1:2,drop=FALSE], p[i,3:4,drop=FALSE], p[i,5])
 		if (addStartEnd) {
 			x <- rbind(p[i,1:2,drop=FALSE], x, p[i,3:4,drop=FALSE])
 		}			
-		#} else {
-		#	n <- as.integer(p[i,5])
-		#	n2 <- n + 2*addStartEnd
-		#	x <- unlist(.C('interm', n, as.double(p[i,1]), as.double(p[i,2]), as.double(p[i,3]), as.double(p[,4]), 
-		#	as.integer(addStartEnd), vector('double', n2), vector('double', n2), PACKAGE='geosphere')[7:8])
-		#	x <- matrix(x, ncol=2)
-		#}
 		if (breakAtDateLine) {
-	
-			r <- range(x[,1]) 
-			r <- r[2] - r[1]
-			if (r > 200) {
-				dif <- abs(x[-nrow(x),1] - x[-1,1])
-				tr <- which(dif==max(dif))
-				x1 <- x[1:tr, ,drop=FALSE]
-				x2 <- x[(tr+1):nrow(x), ,drop=FALSE]
-				if (x1[tr,1] < 0) { 
-					x1[tr,1] <- -180 
-					x2[1,1] <- 180
-				} else { 
-					x1[tr,1] <- 180 
-					x2[1,1] <- -180 
-				}
-				if (nrow(x1) <= 1) {
-					res[[i]] <- x2
-				} else if (nrow(x2) <= 1) {
-					res[[i]] <- x1
-				} else {
-					res[[i]] <- list(x1, x2)
-				}
-			} else {
-				res[[i]] <- x
-			}
+			res[[i]] <- .breakAtDateLine(x)
 		} else {
 			res[[i]] <- x
 		}
@@ -100,13 +95,10 @@ gcIntermediate <- function( p1, p2, n=50, breakAtDateLine=FALSE, addStartEnd=FAL
 				res[[i]] <- Lines( list( Line (res[[i]][[1]]), Line(res[[i]][[2]])), ID=as.character(i))
 			}
 		}
-		
 		res <- SpatialLines(res, CRS("+proj=longlat +ellps=WGS84"))
 		
 	} else if (nrow(p) == 1 ) {
-	
 		res <- res[[1]]
-		
 	} else if (sepNA) {
 		r <- res[[1]]
 		for (i in 2:length(res)) { 
